@@ -37,17 +37,22 @@ THE SOFTWARE.
     #include <experimental/filesystem>
 #endif
 #include "video_demuxer.h"
-#include "roc_bitstream_reader.h"
+#include "rocdecode/roc_bitstream_reader.h"
 #include "roc_video_dec.h"
 #include "ffmpeg_video_dec.h"
 #include "common.h"
 
+//hardcoding for host based decoder creation if demux is not available
+#define DEFAULT_WIDTH 2912
+#define DEFAULT_HEIGHT 1888
+
+
 void ShowHelpAndExit(const char *option = NULL) {
     std::cout << "Options:" << std::endl
     << "-i Input File Path - required" << std::endl
     << "-o Output File Path - dumps output if requested; optional" << std::endl
     << "-d GPU device ID (0 for the first device, 1 for the second, etc.); optional; default: 0" << std::endl
-    << "-backend backend (0 for GPU, 1 CPU-FFMpeg, 2 CPU-FFMpeg No threading); optional; default: 0" << std::endl
+    << "-backend backend (0 for GPU, 1 CPU-FFMpeg); optional; default: 0" << std::endl
     << "-f Number of decoded frames - specify the number of pictures to be decoded; optional" << std::endl
     << "-z force_zero_latency (force_zero_latency, Decoded frames will be flushed out for display immediately); optional;" << std::endl
     << "-disp_delay -specify the number of frames to be delayed for display; optional; default: 1" << std::endl
@@ -89,7 +94,7 @@ int main(int argc, char **argv) {
     int seek_criteria = 0, seek_mode = 0;
     bool b_use_ffmpeg_demuxer = true; // true by default to use FFMPEG demuxer. set to false to use the built-in bitstream reader.
 
-    // Parse command-line arguments
+// Parse command-line arguments
     if(argc <= 1) {
         ShowHelpAndExit();
     }
@@ -259,13 +264,16 @@ int main(int argc, char **argv) {
         if (!backend)   // gpu backend
             viddec = new RocVideoDecoder(device_id, mem_type, rocdec_codec_id, b_force_zero_latency, p_crop_rect, b_extract_sei_messages, disp_delay);
         else {
+        #if ENABLE_HOST_DECODE          
             std::cout << "info: RocDecode is using CPU backend!" << std::endl;
-            bool use_threading = false;
+            uint32_t max_width = b_use_ffmpeg_demuxer ? demuxer->GetWidth() : DEFAULT_WIDTH;
+            uint32_t max_height = b_use_ffmpeg_demuxer ? demuxer->GetHeight() : DEFAULT_HEIGHT;
             if (mem_type == OUT_SURFACE_MEM_DEV_INTERNAL) mem_type = OUT_SURFACE_MEM_DEV_COPIED;    // mem_type internal is not supported in this mode
-            if (backend == 1) {
-                viddec = new FFMpegVideoDecoder(device_id, mem_type, rocdec_codec_id, b_force_zero_latency, p_crop_rect, b_extract_sei_messages, disp_delay);
-            } else
-                viddec = new FFMpegVideoDecoder(device_id, mem_type, rocdec_codec_id, b_force_zero_latency, p_crop_rect, b_extract_sei_messages, disp_delay, true);
+            viddec = new FFMpegVideoDecoder(device_id, mem_type, rocdec_codec_id, b_force_zero_latency, p_crop_rect, b_extract_sei_messages, disp_delay, max_width, max_height);
+        #else
+            std::cout << "Error: RocDecode HOST library is not found and backend is not supported!" << std::endl;
+            return 0;
+        #endif            
         }
 
         if(!viddec->CodecSupported(device_id, rocdec_codec_id, bit_depth)) {
@@ -297,12 +305,12 @@ int main(int argc, char **argv) {
         reconfig_params.p_fn_reconfigure_flush = ReconfigureFlushCallback;
         reconfig_user_struct.b_dump_frames_to_file = dump_output_frames;
         reconfig_user_struct.output_file_name = output_file_path;
+        reconfig_params.reconfig_flush_mode = RECONFIG_FLUSH_MODE_NONE;
         if (dump_output_frames) {
-            reconfig_params.reconfig_flush_mode = RECONFIG_FLUSH_MODE_DUMP_TO_FILE;
-        } else if (b_generate_md5) {
-            reconfig_params.reconfig_flush_mode = RECONFIG_FLUSH_MODE_CALCULATE_MD5;
-        } else {
-            reconfig_params.reconfig_flush_mode = RECONFIG_FLUSH_MODE_NONE;
+            reconfig_params.reconfig_flush_mode |= RECONFIG_FLUSH_MODE_DUMP_TO_FILE;
+        }
+        if (b_generate_md5) {
+            reconfig_params.reconfig_flush_mode |= RECONFIG_FLUSH_MODE_CALCULATE_MD5;
         }
         reconfig_params.p_reconfig_user_struct = &reconfig_user_struct;
 
@@ -349,6 +357,7 @@ int main(int argc, char **argv) {
             }
             n_frame_returned = viddec->DecodeFrame(pvideo, n_video_bytes, pkg_flags, pts, &decoded_pics);
 
+            // get output surface info after the first decoded frame
             if (!n_frame && !viddec->GetOutputSurfaceInfo(&surf_info)) {
                 std::cerr << "Error: Failed to get Output Surface Info!" << std::endl;
                 break;
